.. _science:

Science ('stixpy.science')
**************************

The ``science`` module contains classes and function to read and analysis stix data

.. warning:: The `science` submodule has been depreciate and will be remove in the future please
   use :ref:`product` instead.

.. automodapi:: stixpy.science
